summaryrefslogtreecommitdiffstats
path: root/src/base.c
diff options
context:
space:
mode:
authorJason Evans <jasone@canonware.com>2016-06-01 19:59:02 (GMT)
committerJason Evans <jasone@canonware.com>2016-06-06 03:42:23 (GMT)
commit22588dda6e09f63246064e2e692dc0dded2e8e35 (patch)
treedde3d9fe27f653c5b833f12d7073662cc7946256 /src/base.c
parent0c4932eb1e522211297ae40435ab6d3bd74242bc (diff)
downloadjemalloc-22588dda6e09f63246064e2e692dc0dded2e8e35.zip
jemalloc-22588dda6e09f63246064e2e692dc0dded2e8e35.tar.gz
jemalloc-22588dda6e09f63246064e2e692dc0dded2e8e35.tar.bz2
Rename most remaining *chunk* APIs to *extent*.
Diffstat (limited to 'src/base.c')
-rw-r--r--src/base.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/base.c b/src/base.c
index 3807422..667786e 100644
--- a/src/base.c
+++ b/src/base.c
@@ -38,7 +38,7 @@ base_extent_dalloc(tsdn_t *tsdn, extent_t *extent)
}
static extent_t *
-base_chunk_alloc(tsdn_t *tsdn, size_t minsize)
+base_extent_alloc(tsdn_t *tsdn, size_t minsize)
{
extent_t *extent;
size_t csize, nsize;
@@ -51,13 +51,13 @@ base_chunk_alloc(tsdn_t *tsdn, size_t minsize)
nsize = (extent == NULL) ? CACHELINE_CEILING(sizeof(extent_t)) : 0;
csize = CHUNK_CEILING(minsize + nsize);
/*
* Directly call chunk_alloc_mmap() because it's critical to allocate
* untouched demand-zeroed virtual memory.
*/
{
bool zero = true;
bool commit = true;
- addr = chunk_alloc_mmap(NULL, csize, PAGE, &zero, &commit);
+ addr = extent_alloc_mmap(NULL, csize, PAGE, &zero, &commit);
}
if (addr == NULL) {
if (extent != NULL)
@@ -108,7 +108,7 @@ base_alloc(tsdn_t *tsdn, size_t size)
}
if (extent == NULL) {
/* Try to allocate more space. */
- extent = base_chunk_alloc(tsdn, csize);
+ extent = base_extent_alloc(tsdn, csize);
}
if (extent == NULL) {
ret = NULL;
@@ -51,13 +51,13 @@ base_chunk_alloc(tsdn_t *tsdn, size_t minsize)
csize = CHUNK_CEILING(minsize + nsize);
/*
- * Directly call chunk_alloc_mmap() because it's critical to allocate
+ * Directly call extent_alloc_mmap() because it's critical to allocate
* untouched demand-zeroed virtual memory.
*/